@@ -17,6 +17,35 @@ With SI formatting we denote the use of SI prefixes
 The logic is contained in GetEngInfo
 The interface function (To oasys-wiser) is GetAxisSI
 
+Examples
+x = 0.1e-9
+
+GetEngInfo(x)
+>>> {'SIMant': 1.0, 'SIPow10': -9, 'SIPrefix': 'n', 'EngMant': 1.0, 'EngPow10': -9}
+
+
+GetFormattedEng(x)
+>>> '1e-9'
+
+GetFormattedSI(x)
+>>> '1 n'
+
+
+
+SmartFormatter(x)
+>>> '1 n'
+
+
+SmartFormatter(x, {'unit' : 'm'})
+>>> '1 nm'
+
+
+import numpy as np
+x = np.linspace(-1e-6, 1e-6, 5)
+GetAxisSI(x)
+>>> (array([-1. , -0.5,  0. ,  0.5,  1. ]), 'u')
+change.org
+
 """
 
 
@@ -155,7 +184,8 @@ def GetEngInfo(x, places = None):
 	# of the corner case of values that are beyond
 	# the range of SI prefixes (i.e. > 'Y').
 	_fmant = float("{mant:{fmt}}".format(mant=mant, fmt=fmt))
-	if _fmant >= 1000 and pow10 != max(self.ENG_PREFIXES):
+#	if _fmant >= 1000 and pow10 != max(self.ENG_PREFIXES):
+	if _fmant >= 1000 and pow10 != MAX_ENG_PREFIX:
 		mant /= 1000
 		pow10 += 3
 		
@@ -227,9 +257,14 @@ def SmartFormatter(x, VariableInfo = {'unit' : '', 'prefix':True,'digits':6}):
 	except:
 		UsePrefix = True
 		
+		
+		
 	tp = type(x)
 	if (tp is float) or (tp is int) or (tp is np.float64):
 		
+		#catch if it is a nana
+		if np.isnan(x):
+			return ('NaN')
 		if UsePrefix:
 			try:
 				return GetFormattedSI(x) + VariableInfo['unit']
